@@ -2,7 +2,7 @@
 
 ### OPEN SOURCE LICENSE - GNU AFFERO PUBLIC LICENSE Version 3.0 #######
 #
-#    Net::FullAuto Demonstration GUI
+#    Net::FullAuto AWS Installer Dashboard
 #    Copyright (C) 2000-2016  Brian M. Kelly
 #
 #    This program is free software: you can redistribute it and/or modify
@@ -270,7 +270,7 @@ sub SplitterWindow {
 
      my $button1=wxPerl::Button->new(
          $rightbottom,
-         'Launch + Get Key (.pem)',
+         '<- filename.pem   [AWS EC2]',
          id        => -1,
          position  => [440,15],
          size      => [176,-1],
@@ -284,7 +284,7 @@ sub SplitterWindow {
 
      my $button2=wxPerl::Button->new(
         $rightbottom,
-        'Get AWS  credentials.csv',
+        '<- credentials.csv [AWS IAM]',
         id        => -1,
         position  => [440,45],
         size      => [176,-1],
@@ -297,7 +297,7 @@ sub SplitterWindow {
      EVT_BUTTON( $rightbottom, $button2, \&main::OnClick_button2 );
 
      my $ins=($saved_txt)?'Amazon EC2 Dashboard':
-                          'Instance IP Address';
+                          '<- Instance IP Address  [EC2]';
      my $button3=wxPerl::Button->new(
         $rightbottom,
         $ins,
@@ -551,6 +551,8 @@ sub fullauto_button {
       $self->{ip_txt}=$iptext;
    }
    unless (-e "putty.log") {
+      # http://www.techbout.com/remove-onedrive-windows-10-4548/
+      # https://onedrive.uservoice.com/forums/262982-onedrive/suggestions/9123334-start-onedrive-manually-on-windows-10
       Wx::ExecuteCommand("puttycfg $iptext",wxEXEC_SYNC)
    }
    EVT_WXP_PROCESS_STREAM_EXIT($self, \&evt_process_exit);
@@ -820,8 +822,7 @@ sub OnClick_chkbox3 {
 sub OnClick_button1 {
 
    my ($self, $event) =@_;
-   my $url='https://portal.aws.amazon.com/gp/aws/developer/'.
-           'registration/index.html';
+   my $url='https://console.aws.amazon.com/ec2#KeyPairs:sort=keyName';
    Wx::LaunchDefaultBrowser($url,wxBROWSER_NEW_WINDOW);
 
 }
